@@ -5,7 +5,7 @@
 
 #
 # Copyright (c) 2004 Hewlett-Packard Development Company, L.P.
-#	David Mosberger <davidm@hpl.hp.com>
+# 	David Mosberger <davidm@hpl.hp.com>
 #
 # Scan standard input for GCC warning messages that are likely to
 # source of real 64-bit problems.  In particular, see whether there
@@ -14,29 +14,32 @@
 # crashes.
 #
 
-from __future__ import print_function
-
 import re
 import sys
 
-implicit_pattern = re.compile(r"([^:]*):(\d+): warning: implicit declaration "
-                              + "of function [`']([^']*)'")
+implicit_pattern = re.compile(
+    r"([^:]*):(\d+): warning: implicit declaration " + "of function [`']([^']*)'"
+)
 pointer_pattern = (
     r"([^:]*):(\d+): warning: "
     + r"("
-    +  r"(assignment"
-    +  r"|initialization"
-    +  r"|return"
-    +  r"|passing arg \d+ of `[^']*'"
-    +  r"|passing arg \d+ of pointer to function"
-    +  r") makes pointer from integer without a cast"
+    + r"(assignment"
+    + r"|initialization"
+    + r"|return"
+    + r"|passing arg \d+ of `[^']*'"
+    + r"|passing arg \d+ of pointer to function"
+    + r") makes pointer from integer without a cast"
     + r"|"
-    + r"cast to pointer from integer of different size)")
+    + r"cast to pointer from integer of different size)"
+)
+
+unicode_quote_open = "\u2018"
+unicode_quote_close = "\u2019"
+
 
-unicode_quote_open = '\u2018'
-unicode_quote_close = '\u2019'
 def write(msg):
-    sys.stdout.buffer.write(msg.encode('utf_8', 'backslashreplace'))
+    sys.stdout.buffer.write(msg.encode("utf_8", "backslashreplace"))
+
 
 pointer_pattern = re.compile(pointer_pattern)
 
@@ -45,7 +48,7 @@ last_implicit_linenum = -1
 last_implicit_func = ""
 
 while True:
-    line = sys.stdin.buffer.readline().decode('utf_8', 'replace')
+    line = sys.stdin.buffer.readline().decode("utf_8", "replace")
     if not line:
         break
     # translate unicode open/close quotes to ascii ones
@@ -61,9 +64,16 @@ while True:
         if m:
             pointer_filename = m.group(1)
             pointer_linenum = int(m.group(2))
-            if (last_implicit_filename == pointer_filename
-                and last_implicit_linenum == pointer_linenum):
-                write("Function `%s' implicitly converted to pointer at " \
-                      "%s:%d\n" % (last_implicit_func,
-                                   last_implicit_filename,
-                                   last_implicit_linenum))
+            if (
+                last_implicit_filename == pointer_filename
+                and last_implicit_linenum == pointer_linenum
+            ):
+                write(
+                    "Function `%s' implicitly converted to pointer at "
+                    "%s:%d\n"
+                    % (
+                        last_implicit_func,
+                        last_implicit_filename,
+                        last_implicit_linenum,
+                    )
+                )
